package org.jutils.log;
/*------------------------------------------------------------------------------
Name:      LogConstants.java
Project:   jutils.org
Copyright: jutils.org, see jutils-LICENSE file
Comment:   Global defined logging constants
------------------------------------------------------------------------------*/


/*******************************************************************************
 * This logging constants are required by the logging classes itself and by
 * all systems which use this logging system. <p />
 * There are two possible ways to access the values of this interface.
 * <ol>
 *   <li>by using the full qualified classname (e.g. LogConstants.LOG_WARN)</li>
 *   <li>by inheriting this interface in the other class 
 *       (allows direct access)</li>
 * </ol>
 ******************************************************************************/
public interface LogConstants
{
   /***************************************************************************
    * No logs at all
    **************************************************************************/
   public static final int LOG_NOLOG = 0x0;

   /***************************************************************************
    * Internal error occured
    **************************************************************************/
   public static final int LOG_ERROR = 0x1;

   /***************************************************************************
    * Warning about user actions
    **************************************************************************/
   public static final int LOG_WARN  = 0x2;

   /***************************************************************************
    * Important informational logs only
    **************************************************************************/
   public static final int LOG_INFO  = 0x4;

   /***************************************************************************
    * Trace entry of methods
    **************************************************************************/
   public static final int LOG_CALL  = 0x8;

   /***************************************************************************
    * Show elapsed milliseconds
    **************************************************************************/
   public static final int LOG_TIME  = 0x10;

   /***************************************************************************
    * Trace application flow
    **************************************************************************/
   public static final int LOG_TRACE = 0x20;

   /***************************************************************************
    * Dump internal state
    **************************************************************************/
   public static final int LOG_DUMP  = 0x40;

   /***************************************************************************
    * Marker for plain output
    **************************************************************************/
   public static final int LOG_PLAIN = 0x80;


   /***************************************************************************
    * This is derived value of the boolean cummulation of all other values.
    **************************************************************************/
   public static final int LOG_ALL = LOG_ERROR |
                                     LOG_WARN  |
                                     LOG_INFO  |
                                     LOG_CALL  |
                                     LOG_TIME  |
                                     LOG_TRACE |
                                     LOG_DUMP  |
                                     LOG_PLAIN;
}
