package org.jutils.text;
/*------------------------------------------------------------------------------
Name:      StackTrace.java
Project:   jutils.org
Copyright: jutils.org, see jutils-LICENSE file
Comment:   The named logging instance which delegates the logging task
           to all registered logging devices in this object.
------------------------------------------------------------------------------*/


import java.io.StringWriter;
import java.io.PrintWriter;
import java.lang.StringBuffer;
import java.lang.Throwable;


/**
 * A Helper class to access the stack trace string. 
 *
 * @author Marcel Ruff
 */
public class StackTrace
{
   /**
    * Get the full stacktrace out of a Throwable (Exception and Error)
    * as string
    *
    * @param      t
    *             the throwable to trace.
    * @return     the full stacktrace as string.
    */
   public static final String getStackTrace(Throwable t) {
      StringWriter stringWriter = new StringWriter();
      StringBuffer writerBuffer = stringWriter.getBuffer();
      PrintWriter out = new PrintWriter(stringWriter, false);
      t.printStackTrace(out);
      out.flush();
      return writerBuffer.toString();
   }


   /**
    * Display the current stack<br />
    * Very slow and not filtered for usefulness
    */
   public static final String getStackTrace()
   {
      Throwable throwable = new Throwable();
      return getStackTrace(throwable);
   }
}
