package org.jutils.xml;
/*------------------------------------------------------------------------------
Name:      XMLException.java
Project:   jutils.org
Copyright: jutils.org, see jutils-LICENSE file
Comment:   This XMLException is a common exception object but with the 
           extension to create a XML representation of the Exception.
------------------------------------------------------------------------------*/


/*******************************************************************************
 * This XMLException is a common exception object but with the extension 
 * to create a XML representation of the Exception.
 ******************************************************************************/
public class XMLException 
   extends Exception
{
   public String id;
   public String reason;



   /****************************************************************************
    * Creates a new XMLException.
    * 
    * @param      id 
    *             A unique key for this exception
    * @param      reason 
    *             A nice english text for the end user
    ***************************************************************************/
   public XMLException(String id, String reason)
   {
      this.id = id;
      this.reason = reason;
   }


   /****************************************************************************
    * Creates a string representation of this exception.
    * 
    * @return     a string representation of this exception.
    ***************************************************************************/
   public String toString()
   {
      return toXml();
   }


   /****************************************************************************
    * Create a XML representation of the Exception with the following format:
    * <pre>
    *   &lt;EXCEPTION id='" + id + "'>
    *      &lt;CLASS>JavaClass&lt;/CLASS>
    *      &lt;REASON>&lt;![CDATA[
    *        Reason Text
    *      ]]>&lt;/REASON>
    *   &lt;/EXCEPTION>
    * </pre>
    ***************************************************************************/
   public String toXml()
   {
      StringBuffer buf = new StringBuffer(reason.length() + 120);
      buf.append("<EXCEPTION id='").append(id).append("'>\n");
      buf.append("   <CLASS>").append(getClass().getName()).append("</CLASS>\n");
      buf.append("   <REASON><![CDATA[").append(reason).append("]]></REASON>\n");
      buf.append("</EXCEPTION>");
      return buf.toString();
   }
}
